@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Union, overload
 
 import numba
 import numpy as np
@@ -24,7 +24,10 @@ def _quantile_normalize(_in_arr: np.ndarray) -> np.ndarray:
     # sorted- rowmeans, vals, and idx are helper arrays which we need to fill
     # get the value for an index
     sorted_val = np.empty(shape=(n_rows, n_cols), dtype=np.float64)
-    sorted_idx = np.empty(shape=(n_rows, n_cols), dtype=np.uint32)
+    # noinspection PyUnresolvedReferences
+    sorted_idx = np.empty(
+        shape=(n_rows, n_cols), dtype=np.uint32  # type: ignore
+    )
     sorted_rowmeans = np.empty(shape=n_rows, dtype=np.float64)
     for col_i in range(n_cols):
         argsort = np.argsort(_in_arr[:, col_i])
@@ -32,7 +35,7 @@ def _quantile_normalize(_in_arr: np.ndarray) -> np.ndarray:
         sorted_val[:, col_i] = np.array([_in_arr[i, col_i] for i in argsort])
 
     for row in range(n_rows):
-        sorted_rowmeans[row] = np.mean(sorted_val[row])
+        sorted_rowmeans[row] = np.mean(sorted_val[row, :])
 
     # we quantile normalize separately per column
     for col_i in range(n_cols):
@@ -64,6 +67,15 @@ def _quantile_normalize(_in_arr: np.ndarray) -> np.ndarray:
     return qnorm
 
 
+# fmt: off
+# function overloading for the correct return type depending on the input
+@overload
+def quantile_normalize(data: pd.DataFrame) -> pd.DataFrame: ...
+@overload
+def quantile_normalize(data: np.ndarray) -> np.ndarray: ...
+# fmt: on
+
+
 def quantile_normalize(
     data: Union[pd.DataFrame, np.ndarray]
 ) -> Union[pd.DataFrame, np.ndarray]:
@@ -83,5 +95,7 @@ def quantile_normalize(
         qn_data[:] = _quantile_normalize(qn_data.values)
     elif isinstance(data, np.ndarray):
         qn_data = _quantile_normalize(data)
+    else:
+        raise NotImplementedError
 
     return qn_data
